==> haskell-digest-0.0.1.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: digest
version: 0.0.1.2
id: digest-0.0.1.2-I31fG7Yb9KfF2Ii6LMYpjd
key: digest-0.0.1.2-I31fG7Yb9KfF2Ii6LMYpjd
license: BSD-3-Clause
copyright: (c) 2009 Eugene Kirpichov
maintainer: Eugene Kirpichov <ekirpichov@gmail.com>
author: Eugene Kirpichov <ekirpichov@gmail.com>
stability: provisional
synopsis: Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.
description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.
category: Cryptography
abi: cdd89248c574415f5b3de58ee5403f9d
exposed: True
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32
import-dirs: /usr/lib/ghc-8.4.3/site-local/digest-0.0.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/digest-0.0.1.2
hs-libraries: HSdigest-0.0.1.2-I31fG7Yb9KfF2Ii6LMYpjd
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html: /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digest-0.0.1.2-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: digest
version: 0.0.1.2
id: digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN
key: digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN
license: BSD-3-Clause
copyright: (c) 2009 Eugene Kirpichov
maintainer: Eugene Kirpichov <ekirpichov@gmail.com>
author: Eugene Kirpichov <ekirpichov@gmail.com>
stability: provisional
synopsis: Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.
description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.
category: Cryptography
abi: 809e052fc748fe8acc8fff02a7bd37eb
exposed: True
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32
import-dirs: /usr/lib/ghc-8.6.1/site-local/digest-0.0.1.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/digest-0.0.1.2
hs-libraries: HSdigest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html: /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
